EOxServer
=========

.. image:: https://travis-ci.org/EOxServer/eoxserver.svg?branch=master
   :target: https://travis-ci.org/EOxServer/eoxserver

.. image:: https://badge.fury.io/py/EOxServer.svg
    :target: https://pypi.org/project/EOxServer/

.. image:: https://readthedocs.org/projects/eoxserver/badge/?version=master
    :alt: Documentation Status
    :scale: 100%
    :target: http://docs.eoxserver.org/en/master

EOxServer is a Python application and framework for presenting Earth
Observation (EO) data and metadata.

EOxServer implements the `OGC <http://www.opengeospatial.org/>`_
Implementation Specifications EO-WCS and EO-WMS on top of
`MapServer's <http://mapserver.org>`_
`WCS <http://www.opengeospatial.org/standards/wcs>`_ and
`WMS <http://www.opengeospatial.org/standards/wms>`_ implementations.

EOxServer is released under the `EOxServer Open License
<http://eoxserver.org/doc/copyright.html>`_ a MIT-style
license and written in `Python <http://www.python.org/>`_ and entirely based on
Open Source software including `MapServer <http://mapserver.org>`_,
`Django/GeoDjango <https://www.djangoproject.com>`_,
`GDAL <http://www.gdal.org>`_,
`SpatiaLite <http://www.gaia-gis.it/spatialite/>`_, or
`PostGIS <http://postgis.refractions.net/>`_, and
`PROJ.4 <http://trac.osgeo.org/proj/>`_.

More information is available at `http://eoxserver.org <http://eoxserver.org>`_.
